Learn R Programming

RmiR (version 1.28.0)

RmiRtc: Time Course relationship between microRNA and Genes

Description

Given a timeline of experiments resulting from RmiR or read.mir, it calculates the correlation between the trend of miRNA and corresponding gene targets.

Usage

RmiRtc(timeline = NULL, timevalue = NULL, method = "pearson") readRmiRtc(miRtcObj, correlation = -0.75, exprLev = 1, annotation= NULL, fileName = "miRNA_for_genes")

Arguments

timeline
A vector with the names of the experiments resulting from RmiR or read.mir, in chronological order.
timevalue
A vector of numbers with the unity of time correspondig to timeline.
method
Method to use to calculate the correlation between miRNA and gene expression, default is "pearson". For other see cor from stats package.
miRtcObj
An object resulting from RmiRtc.
annotation
The annotation package to retrive the corresponding symbol given the gene_id . eg: Agilent 44k annotation="hgug4112a.db" or annotation="org.Hs.eg.db".
correlation
The correlation level desired to filter the miRtcList object created with the RmiRtc function.
exprLev
The absolute value of gene expression as cut-off to filter the miRtcList object created with the RmiRtc function.
fileName
The file name to print the file with the gene targets with the number of miRNAs matching the correlation criteria. If nothing is specified, no file will be created.

Value

couples
The couples of mature_miRNA and targets in entrez gene annotation.
mirExpr
A matrix with the expression of miRNA in order by timeline.
geneExpr
A matrix with the expression of miRNA in order by timeline.
mirCV
A matrix with the coefficents of variation of the miRNAs from RmiR or read.mir.
geneCV
A matrix with the coefficents of variation of the genes resulting from RmiR or read.mir.
correlation
A vector with the correlation value between miRNAs and gene targets.
reps
With readRmiRtc we list all the gene targets ordered by the number of miRNAs matching the correlation criteria.

Details

RmiRtc creates an miRtcList wich includes all the information of the time course experiment: couples of miRNA and gene target, expression of gene and miRNA in the time, the correlation between the miRNA and the gene expression trends. readRmiRtc subsets the miRtcList created with RmiRtc. We can select a correlation level, if positive we select the correlated genes and miRNas, if negative the anti-correlated couples. Also we can decrease the data by setting a log ratio cut off for the gene expression, to select only the case which the a gene is op or down regulated.

See Also

RmiR, read.mir, plotRmiRtc

Examples

Run this code
	##An example without the data
	data(RmiR)
	res1 <- read.mir(genes=gene1, mirna=mir1, annotation="hgug4112a.db")
	res2 <- read.mir(genes=gene2, mirna=mir2, annotation="hgug4112a.db")
	res3 <- read.mir(genes=gene3, mirna=mir3, annotation="hgug4112a.db")
	
	res_tc <- RmiRtc(timeline=c("res1", "res2", "res3"),
			 timevalue=c(12,48,72))
	res <- readRmiRtc(res_tc, correlation=-0.9, exprLev=1, 
			  annotation="hgug4112a.db")
	res$reps

Run the code above in your browser using DataLab